<div class="columns is-desktop" role="navigation" aria-label="Secondary">
  <!-- MetaColumn 1 -->
  <div class="column">
    <div class="columns is-mobile">
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="{{ url_for('about')}}">About arXiv</a></li>
          <li><a href="{{ url_for('team')}}">Leadership Team</a></li>
        </ul>
      </div>
      <div class="column">
        <ul class="nav-spaced">
          <li><span class="icon"><i class="fa fa-envelope"></i></span><a href="{{ url_for('contact') }}"> Contact</a></li>
          <li><span class="icon"><i class="fa fa-twitter"></i></span><a href="{{ url_for('twitter') }}"> <span class="is-hidden-mobile">Follow us on</span> Twitter</a></li>
        </ul>
      </div>
    </div>
  </div> <!-- end MetaColumn 1 -->
  <!-- MetaColumn 2 -->
  <div class="column">
    <div class="columns is-mobile">
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="{{ url_for('help') }}">Help</a></li>
          <li><a href="{{ url_for('privacy_policy') }}">Privacy Policy</a></li>
        </ul>
      </div>
      <div class="column">
        <ul class="nav-spaced">
          <li><a href="{{ url_for('blog') }}">Blog</a></li>
          <li><a href="{{ url_for('subscribe') }}"> Subscribe</a></li>
        </ul>
      </div>
    </div>
  </div> <!-- end MetaColumn 2 -->
</div>

<div class="columns" style="border-top: 1px solid #979797">
  <div class="column">
    <p class="help">arXiv&#174; is a registered trademark of Cornell University.</p>
  </div>
  <div class="column">
    <p class="help">If you have a disability and are having trouble accessing information
      on this website or need materials in an alternate format, contact
      <a href="{{ A11Y_URL }}">web-accessibility@cornell.edu</a> for
       assistance.</p>
  </div>
</div>
