<!DOCTYPE html>
<html lang="en">
  <head>
    {% include "base/head.html" %}
    <!-- Custom style sheets or other head includes -->
    {% block addl_head %}
    {% endblock addl_head %}
  </head>
  <body>
  {% import "base/macros.html" as macros %}
  <noscript><p><img src="https://webstats.arxiv.org/matomo.php?idsite=1&amp;rec=1" style="border:0;" alt="" /></p></noscript>
  <a href="#main-container" class="is-sr-only">Skip to main content</a>
  <header>
    {% block header %}
    {% include "base/header.html" %}
    {% endblock header %}
  </header>

  <main role="main" class="container" id="main-container">
    {% with messages = get_alerts() -%}
      {% if messages -%}
        <div class="notifications" role="alert">
          {% for category, message in messages -%}
            <div class="notification is-{{ category }}">
              {% if message.dismissable %}<button class="delete notification-dismiss"></button>{% endif %}
              {% if message.title %}<h2 class="is-size-5 is-marginless">{{ message.title }}</h2>{%- endif %}
              <p>{{ message.message }}</p>
            </div>
          {%- endfor %}
        </div>
      {%- endif %}
    {%- endwith %}

    {% block content %}
    {% endblock content %}
  </main>

  <footer>
    {% block footer %}
    {% include "base/footer.html" %}
    {% endblock footer %}
  </footer>
  </body>
</html>
