@import url('https://fonts.googleapis.com/css?family=Open+Sans:400,400i,600,700')

// Variables, inspired by Spacelab theme https://jenil.github.io/bulmaswatch/spacelab/
$grey-darker: #2d2d2d
$grey-dark: #333
$grey: #757575
$grey-light: hsl(0, 0%, 60%)
$grey-lighter: hsl(0, 0%, 80%)

$orange: #d47500
$green: #3cb521
$blue: #0068ac
$red: #cd0200

$slate: #446e9b
$slate-invert: #fff

$cul-gray: #222
$cul-red: #b31b1b
$cul-red-darker: darken($cul-red, 15%)
$cul-red-darker-invert: #fff

$primary: $cul-red
$primary-invert: #fff
$warning: $orange
$warning-invert: #fff

$custom-colors: $cul-red-darker

$subtitle-color: $grey

$navbar-item-active-color: $primary
$navbar-item-hover-background-color: transparent

$family-sans-serif: 'Open Sans', 'Lucida Grande', 'Helvetica Neue', Helvetica, Arial, sans-serif
$family-smalltext: 'Lucida Grande', 'Helvetica Neue', Helvetica, Arial, sans-serif

$size-7: .85rem
/* changed when base text size is 14px */

$box-padding: .75rem
$box-radius: 2px

$message-body-border-width: 1px
$message-header-body-border-width: 1px

$subtitle-color: $grey

$navbar-item-active-color: $primary
$navbar-item-hover-background-color: transparent

$notification-padding: .75rem 1.25rem

$button-hover-color: hsl(0, 0%, 50%)

@import 'bulma/bulma'
@import 'extensions/bulma-switch/switch'
@import '_overrides'
@import '_custom'
