{% extends "base/base.html" %}

{% block content %}
<h1>arXiv Style Test Page</h1>

<section class="section box has-background-light">
  <div class="columns">
    <div class="column is-narrow has-text-centered">
      <h2>Admin</h2>
      <div class="field">
        <div class="control has-text-centered">
          <a class="button is-outlined is-link" href="">Download current as .tar</a>
        </div>
      </div>
      <div class="field">
        <div class="control has-text-centered">
          <a class="button is-outlined is-link" href="">Create checkpoint</a>
        </div>
      </div>
      <div class="field">
        <div class="control">
          <input id="switchRoundedDanger" type="checkbox" name="switchRoundedDanger" class="switch is-rounded is-danger" checked="checked">
            <label for="switchRoundedDanger">LOCKED</label>
          <span>Admin One 2019-04-20</span>
        </div>
      </div>
    </div>
    <div class="column">
      <h3>Checkpoints</h3>
      <div class="level has-background-white is-marginless" style="padding: 0.5em">
        <div class="level-left">
          <span class="level-item">
            2019-04-11T09:57:00Z
          </span>
          <span class="level-item">
            Title might be longer than this
          </span>
        </div>
        <div class="level-right">
          <div class="level-item">
            <div class="field">
              <div class="control">
                <a href="" class="button is-link is-outlined is-small">Make current</a>
                <a href="" class="button is-link is-outlined is-small">Download</a>
                <a href="" class="button is-link is-outlined is-small"><span class="icon">
                  <i class="fa fa-trash"><span class="sr-only">Delete this checkpoint</span></i>
                </span></a>
              </div>
            </div>
          </div>
        </div>
      </div>
      <div class="level has-background-grey-lighter is-marginless" style="padding: 0.5em">
        <div class="level-left">
          <span class="level-item">
            2019-04-11T09:57:00Z
          </span>
          <span class="level-item">
            Title might be longer than this
          </span>
        </div>
        <div class="level-right">
          <div class="level-item">
            <div class="field">
              <div class="control">
                <a href="" class="button is-link is-outlined is-small">Make current</a>
                <a href="" class="button is-link is-outlined is-small">Download</a>
                <a href="" class="button is-link is-outlined is-small"><span class="icon">
                  <i class="fa fa-trash"><span class="sr-only">Delete this checkpoint</span></i>
                </span></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</section>

<div class="message">
  <div class="message-body">
    <h2>Header 2</h2>
    <p>This is a message box. It is currently the default color.</p>
  </div>
</div>
<div class="message is-primary">
  <div class="message-header">
    <h3 class="is-marginless has-text-white">This Message is Header 3, marginless, white</h3>
  </div>
  <div class="message-body">
    <p>You can also change the message colors and add a header.</p>
  </div>
</div>
<h4>This is just testing header 4</h4>
<ul>
  <li>and list items</li>
  <li>just in case</li>
  <li>and a list item with <br />
    multiple lines</li>
  <li>to test line breaks</li>
  <li class="help">and small type of class help</li>
</ul>
<hr>
<h2>Search Results Sample</h2>
<div class="breathe-horizontal">
  <div class="field has-addons-tablet">
    <div class="control is-expanded">
      <label for="query" class="is-sr-only">Search term or terms</label>
        <input class="input is-medium" id="query" name="query" placeholder="Search term..." type="text" value="red dwarf">
    </div>
    <div class="select control is-medium">
      <label class="is-hidden" for="searchtype">Field</label>
      <select class="is-medium" id="searchtype" name="searchtype"><option selected value="all">All fields</option><option value="title">Title</option><option value="author">Author(s)</option><option value="abstract">Abstract</option><option value="comments">Comments</option><option value="journal_ref">Journal reference</option><option value="acm_class">ACM classification</option><option value="msc_class">MSC classification</option><option value="report_num">Report number</option><option value="paper_id">arXiv identifier</option><option value="doi">DOI</option><option value="orcid">ORCID</option><option value="author_id">arXiv author ID</option><option value="help">Help pages</option><option value="full_text">Full text</option></select>
    </div>
    <div class="control">
        <button class="button is-link is-medium">Search</button>
    </div>
  </div>
  <div class="field">
    <div class="control is-size-7">
      <label class="radio">
        <input checked id="abstracts-0" name="abstracts" type="radio" value="show"> Show abstracts
      </label>
      <label class="radio">
        <input id="abstracts-1" name="abstracts" type="radio" value="hide"> Hide abstracts
      </label>
    </div>
  </div>
  <div class="is-clearfix" style="height: 2.5em">
    <div class="is-pulled-right">
      <a href="/search/advanced?terms-0-term=red+dwarf&amp;terms-0-field=all&amp;size=50&amp;order=-announced_date_first">Advanced Search</a>
    </div>
  </div>
</div>
<div class="breathe-horizontal">
  <div class="level is-marginless">
    <p class="list-title level-left">
      <a href="https://arxiv.org/abs/1807.07625">arXiv:1807.07625</a>
      <span>&nbsp;[<a href="https://arxiv.org/pdf/1807.07625">pdf</a>, <a href="https://arxiv.org/format/1807.07625">other</a>]&nbsp;</span>
      <span class="tag is-small is-link tooltip is-tooltip-right" data-tooltip="Astrophysics of Galaxies">astro-ph.GA</span>
      </p>
  </div>

  <p class="title is-5 mathjax">
      A comprehensive comparison between APOGEE and LAMOST: Radial Velocities and Atmospheric Stellar Parameters
  </p>
  <p class="authors">
    <span class="has-text-black-bis has-text-weight-semibold">Authors:</span>
    <a href="/search/?searchtype=author&amp;query=Anguiano%2C+B">B. Anguiano</a>,
    <a href="/search/?searchtype=author&amp;query=Majewski%2C+S+R">S. R. Majewski</a>,
    <a href="/search/?searchtype=author&amp;query=Allende-Prieto%2C+C">C. Allende-Prieto</a>,
    <a href="/search/?searchtype=author&amp;query=Meszaros%2C+S">S. Meszaros</a>,
    <a href="/search/?searchtype=author&amp;query=J%C3%B6nsson%2C+H">H. Jönsson</a>,
    <a href="/search/?searchtype=author&amp;query=Garc%C3%ADa-Hern%C3%A1ndez%2C+D+A">D. A. García-Hernández</a>,
    <a href="/search/?searchtype=author&amp;query=Beaton%2C+R+L">R. L. Beaton</a>,
    <a href="/search/?searchtype=author&amp;query=Stringfellow%2C+G+S">G. S. Stringfellow</a>,
    <a href="/search/?searchtype=author&amp;query=Cunha%2C+K">K. Cunha</a>,
    <a href="/search/?searchtype=author&amp;query=Smith%2C+V+V">V. V. Smith</a>
  </p>

  <p class="abstract mathjax">
    <span class="search-hit">Abstract</span>:
    <span class="abstract-short has-text-grey-dark mathjax" id="1807.07625v1-abstract-short" style="display: inline;">
      &hellip;velocities and the main stellar atmospheric parameters for stars in common between the latest data releases from the APOGEE and the LAMOST surveys. There is a total of 42,420 <span class="search-hit mathjax">dwarfs</span>/giants stars in common between the APOGEE DR14 - LAMOST DR3 stellar catalogs. A comparison between the RVs shows an offset of 4.54 $\pm$ 0.03 km/s, with a dispersion of 5.8 km/s,&hellip;
      <a class="is-size-7" style="white-space: nowrap;" href="#">&#9661; More</a>
    </span>
  </p>

  <p class="is-size-7"><span class="has-text-black-bis has-text-weight-semibold">Submitted</span> 19 July, 2018;
    <span class="has-text-black-bis has-text-weight-semibold">originally announced</span> July 2018.
  </p>

  <p class="comments is-size-7">
    <span class="has-text-black-bis has-text-weight-semibold">Comments:</span>
    <span class="has-text-grey-dark mathjax">14 pages, 20 figures. Accepted for publication in Astronomy &amp; Astrophysics (A&amp;A)</span>
  </p>
</div>

<h2>List of buttons for testing hover/active/focus states</h2>
<div class="buttons">
  <button class="button" href="#">Default</button>
  <button class="button is-link" href="#">Default</button>
  <button class="button is-primary" href="#">Default</button>
  <button class="button is-danger" href="#">Default</button>
  <button class="button is-warning" href="#">Default</button>
  <button class="button is-success" href="#">Default</button>
</div>
{% endblock content %}
